package HPSG::Mason;
use strict;

=head1 NAME

HPSG::Mason - Mason components for rendering Head-driven Phrase Structure Grammar feature structures to \LaTeX

=head1 VERSION

Version 0.01

=cut

our $VERSION = '0.01';

=head1 SYNOPSIS

  see HPSG::Mason::Interp

=cut

=head1 AUTHOR

C.J. Adams-Collier, C<< <cjac at u.washington.edu> >>

=head1 BUGS

Please report any bugs or feature requests to C<bug-hpsg-mason at rt.cpan.org>, or through
the web interface at L<http://rt.cpan.org/NoAuth/ReportBug.html?Queue=HPSG-Mason>.  I will be notified, and then you'll
automatically be notified of progress on your bug as I make changes.




=head1 SUPPORT

You can find documentation for this module with the perldoc command.

    perldoc HPSG::Mason


You can also look for information at:

=over 4

=item * RT: CPAN's request tracker

L<http://rt.cpan.org/NoAuth/Bugs.html?Dist=HPSG-Mason>

=item * AnnoCPAN: Annotated CPAN documentation

L<http://annocpan.org/dist/HPSG-Mason>

=item * CPAN Ratings

L<http://cpanratings.perl.org/d/HPSG-Mason>

=item * Search CPAN

L<http://search.cpan.org/dist/HPSG-Mason>

=back


=head1 ACKNOWLEDGEMENTS


=head1 COPYRIGHT & LICENSE

Copyright 2009 C.J. Adams-Collier, all rights reserved.

This program is free software; you can redistribute it and/or modify it
under the same terms as Perl itself.


=cut

1; # End of HPSG::Mason
